@@ -596,8 +596,10 @@ failbadinput (json_parse_t * parser)
 			    type_names[parser->bad_type]);
     EROVERFLOW;
     if (parser->bad_beginning) {
+	int bad_byte;
+	bad_byte = (int) parser->bad_beginning - (int) parser->input + 1;
 	string_end += snprintf (SNEND, SNSIZE, " starting from byte %d",
-				parser->bad_beginning - parser->input + 1);
+				bad_byte);
 	EROVERFLOW;
     }
 
